@@ -357,7 +357,7 @@ class BMC(object):
     def fru_show(self, filename):
         return self.handle.fru_show(filename=filename)
 
-    def lan_print(self, channel=''):
+    def lan_print(self, channel=None):
         return self.handle.lan_print(channel=channel)
 
     def lan_set(self, channel, command, param):
@@ -399,7 +399,7 @@ class BMC(object):
                                      channel=channel)
     """Fabric commands
 
-    In pyipmi/fabric.py, these commands are mapped to classes that 
+    In pyipmi/fabric.py, these commands are mapped to classes that
     are subclasses of the Command class. Those subclasses contain the
     string arguments that are run by pyipmi/ipmitool.py
 
@@ -450,13 +450,53 @@ class BMC(object):
     def fabric_get_uplink_info(self):
         return self.handle.fabric_getuplinkinfo()
 
+    def fabric_set_chassis_serial_num(self, serial):
+        return self.handle.fabric_setchassisserialnum(serial=serial)
+
+    def fabric_get_chassis_serial_num(self):
+        return self.handle.fabric_getchassisserialnum()
+
+    def fabric_get_uplink_status(self):
+        return self.handle.fabric_get_uplink_status()
+
     """Fabric config commands
 
-    In pyipmi/fabric_config.py, these commands are mapped to classes that 
+    In pyipmi/fabric_config.py, these commands are mapped to classes that
     are subclasses of the Command class. Those subclasses contain the
     string arguments that are run by pyipmi/ipmitool.py
 
     """
+    def fabric_config_get_network_mac(self, mac):
+        return self.handle.fabric_config_get_network_mac(mac=mac)
+
+    def fabric_config_set_mac(self, mac, network):
+        return self.handle.fabric_config_set_mac(mac=mac, network=network)
+
+    def fabric_config_add_network(self, name, uplink=None, private=False):
+        return self.handle.fabric_config_add_network(
+            name=name,
+            uplink=uplink,
+            private=private
+        )
+
+    def fabric_config_rm_network(self, name, uplink=None):
+        return self.handle.fabric_config_rm_network(name=name, uplink=uplink)
+
+    def fabric_config_get_uplinks(self, filename, tftp_addr=None):
+        return self.handle.fabric_config_get_uplinks(filename=filename,
+                                            tftp_addr=tftp_addr)
+
+    def fabric_config_get_networks(self, filename, tftp_addr=None):
+        return self.handle.fabric_config_get_networks(filename=filename,
+                                            tftp_addr=tftp_addr)
+
+    def fabric_config_get_uplink_mode(self):
+        return self.handle.fabric_config_get_uplink_mode()
+
+    def fabric_config_set_uplink_mode(self, uplink_mode):
+        return self.handle.fabric_config_set_uplink_mode(
+            uplink_mode=uplink_mode
+        )
 
     def fabric_config_update_config(self):
         return self.handle.fabric_config_updateconfig()
@@ -530,6 +570,17 @@ class BMC(object):
     def fabric_config_set_defgw(self, ipaddr):
         return self.handle.fabric_config_set_defgw(ipaddr=ipaddr)
 
+    def fabric_config_set_nodenum_offset(self, offset):
+        return self.handle.fabric_config_set_nodenum_offset(offset=offset)
+
+    def fabric_config_add_sc_route(self, node_start, node_end, guardian_node_id):
+        return self.handle.fabric_config_add_sc_route(
+                node_start=node_start, node_end=node_end, via=guardian_node_id)
+
+    def fabric_config_get_sc_discovery(self, filename, tftp_addr=None):
+        return self.handle.fabric_config_get_sc_discovery(
+            filename=filename, tftp_addr=tftp_addr)
+
     def set_bootdev(self, device, options=None):
         return self.handle.bootdev_set(device=device, options=options)
 
@@ -580,6 +631,10 @@ class BMC(object):
         return self.handle.fabric_info_getdepthchart(filename=filename,
                                                      tftp_addr=tftp_addr)
 
+    def fabric_info_partition_config(self, filename, tftp_addr=None):
+        return self.handle.fabric_info_partition_config(filename=filename,
+                                                        tftp_addr=tftp_addr)
+
     def pmic_get_version(self):
         return self.handle.pmic_get_version()
 
